==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/UserFactorActivateResponseLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import com.okta.sdk.resource.model.LinksUserUser;
import com.okta.sdk.resource.model.LinksVerifyVerify;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorActivateResponseLinks
 */
@JsonPropertyOrder({ UserFactorActivateResponseLinks.JSON_PROPERTY_SELF,
        UserFactorActivateResponseLinks.JSON_PROPERTY_USER, UserFactorActivateResponseLinks.JSON_PROPERTY_VERIFY })
@JsonTypeName("UserFactorActivateResponse__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class UserFactorActivateResponseLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_USER = "user";
    private LinksUserUser user;

    public static final String JSON_PROPERTY_VERIFY = "verify";
    private LinksVerifyVerify verify;

    public UserFactorActivateResponseLinks() {
    }

    public UserFactorActivateResponseLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public UserFactorActivateResponseLinks user(LinksUserUser user) {

        this.user = user;
        return this;
    }

    /**
     * Get user
     *
     * @return user
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksUserUser getUser() {
        return user;
    }

    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUser(LinksUserUser user) {
        this.user = user;
    }

    public UserFactorActivateResponseLinks verify(LinksVerifyVerify verify) {

        this.verify = verify;
        return this;
    }

    /**
     * Get verify
     *
     * @return verify
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksVerifyVerify getVerify() {
        return verify;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerify(LinksVerifyVerify verify) {
        this.verify = verify;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorActivateResponseLinks userFactorActivateResponseLinks = (UserFactorActivateResponseLinks) o;
        return Objects.equals(this.self, userFactorActivateResponseLinks.self)
                && Objects.equals(this.user, userFactorActivateResponseLinks.user)
                && Objects.equals(this.verify, userFactorActivateResponseLinks.verify);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, user, verify);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorActivateResponseLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    user: ").append(toIndentedString(user)).append("\n");
        sb.append("    verify: ").append(toIndentedString(verify)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/UserFactorActivateResponseLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import com.okta.sdk.resource.model.LinksUserUser;
import com.okta.sdk.resource.model.LinksVerifyVerify;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorActivateResponseLinks
 */
@JsonPropertyOrder({ UserFactorActivateResponseLinks.JSON_PROPERTY_SELF,
        UserFactorActivateResponseLinks.JSON_PROPERTY_USER, UserFactorActivateResponseLinks.JSON_PROPERTY_VERIFY })
@JsonTypeName("UserFactorActivateResponse__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserFactorActivateResponseLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_USER = "user";
    private LinksUserUser user;

    public static final String JSON_PROPERTY_VERIFY = "verify";
    private LinksVerifyVerify verify;

    public UserFactorActivateResponseLinks() {
    }

    public UserFactorActivateResponseLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public UserFactorActivateResponseLinks user(LinksUserUser user) {

        this.user = user;
        return this;
    }

    /**
     * Get user
     *
     * @return user
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksUserUser getUser() {
        return user;
    }

    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUser(LinksUserUser user) {
        this.user = user;
    }

    public UserFactorActivateResponseLinks verify(LinksVerifyVerify verify) {

        this.verify = verify;
        return this;
    }

    /**
     * Get verify
     *
     * @return verify
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksVerifyVerify getVerify() {
        return verify;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerify(LinksVerifyVerify verify) {
        this.verify = verify;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorActivateResponseLinks userFactorActivateResponseLinks = (UserFactorActivateResponseLinks) o;
        return Objects.equals(this.self, userFactorActivateResponseLinks.self)
                && Objects.equals(this.user, userFactorActivateResponseLinks.user)
                && Objects.equals(this.verify, userFactorActivateResponseLinks.verify);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, user, verify);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorActivateResponseLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    user: ").append(toIndentedString(user)).append("\n");
        sb.append("    verify: ").append(toIndentedString(verify)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
